@@ -44,6 +44,7 @@ class DingDingPlugin(NotificationPlugin):
         """
         Process error.
         """
+        print(event.__dict__)
         if not self.is_configured(group.project):
             return
 
@@ -53,6 +54,7 @@ class DingDingPlugin(NotificationPlugin):
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
         title = u"New alert from {}".format(event.project.slug)
+        linkUrl = u"{}events/{}/".format(group.get_absolute_url(), event.event_id)
 
         data = {
             "msgtype": "markdown",
@@ -61,7 +63,7 @@ class DingDingPlugin(NotificationPlugin):
                 "text": u"#### {title} \n > {message} [href]({url})".format(
                     title=title,
                     message=event.message,
-                    url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
+                    url=linkUrl,
                 )
             }
         }
